/* Vampire Attack 2 Construction Set
 * Copyright (C) 2009-2010 Blazing Games Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @author Billy D. Spelchan
 * @version 1.00
 */
package com.blazinggames.va2cs;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

public class GridButton 
extends Canvas 
implements MouseListener {

// ***** VARIABLES ****************************************************

		/**
	 * 
	 */
	private static final long serialVersionUID = 6444410525367235803L;
		private Image _imagestrip;
		private Dimension _imageSize;
		private Dimension _imageLayoutSize;
		private Dimension _buttonSize;
		private Color _backColor;
		private Color _selectedColor;
		private int _buttonsPerRow;
		private int _numButtons;
		private int _selected;
		

// ***** CONSTRUCTORS *************************************************
		/**
		 * 
		 */
		public GridButton()
		{
			super();

			_imagestrip = null;
			_imageSize = new Dimension(1, 1);
			_imageLayoutSize = new Dimension(1, 1);
			_buttonSize = new Dimension (1, 1);
			_backColor = Color.white;
			_selectedColor = Color.red;
			_buttonsPerRow = 1;
			_numButtons = 1;
			_selected = 0;
			addMouseListener(this);
		}

		public GridButton(Image strip, int twidth, int theight, int gwidth, int gheight)
		{
			this();
			_imagestrip = strip;
			_imageSize.setSize(twidth, theight);
			_buttonSize.setSize(twidth, theight);
			_imageLayoutSize.setSize(gwidth, gheight);
			_buttonsPerRow = gwidth;
			_numButtons = gwidth * gheight;
		}


// ***** METHODS - From Canvas **************************************

		public void paint(Graphics g)
		{
			g.setColor(_backColor);
			g.fillRect(0,0, getWidth(), getHeight());

			int numRows = _numButtons / _buttonsPerRow;
			int sx = 0;
			int sy = 0;
			int basedx = (_buttonSize.width - _imageSize.width) / 2;
			int dx = basedx;
			int basedy = (_buttonSize.height - _imageSize.height) / 2;
			int dy = basedy;
	        int id = 0;
			for (int cntrY = 0; cntrY < numRows; ++cntrY)
			{
				for (int cntrX = 0; cntrX < _buttonsPerRow; ++cntrX)
				{
					sx = (id % _imageLayoutSize.width) * _imageSize.width;
	                sy = (id / _imageLayoutSize.width) * _imageSize.height;
					g.drawImage(_imagestrip, dx, dy, dx + _imageSize.width, dy + _imageSize.height,
								sx, sy, sx + _imageSize.width, sy + _imageSize.height, this);
	                ++id;
					dx += _buttonSize.width;
				}
				dx = basedx;
				dy += _imageSize.height;
			}
			g.setColor(_selectedColor);
			sx = (_selected % _buttonsPerRow) * _buttonSize.width + basedx;
			sy = (_selected / _buttonsPerRow) * _buttonSize.height + basedy;
			g.drawRect(sx-1, sy-1, _imageSize.width+2, _imageSize.height+2);
		}
		
		public Dimension getPreferredSize()
		{
//	        System.out.println("BPR = " + _buttonsPerRow);
//	        System.out.println("ButtonSize = " + _buttonSize.width);
			return new Dimension(_buttonsPerRow * _buttonSize.width, (_numButtons / _buttonsPerRow) * _buttonSize.height);
		}


// ***** METHODS - Getting and Setting **********************************************

		public void setImage(Image i, int tw, int th, int cols, int rows)
		{
			_imagestrip = i;
	   		_imageSize.setSize(tw, th);
	   		_imageLayoutSize.setSize(cols, rows);
		}
		
		public void setButtonSize(int w, int h)
		{
			_buttonSize.setSize(w, h);
		}
		
		public void setBackground(Color c)
		{
			_backColor = c;
		}

		public void setSelectedColor(Color c)
		{
			_selectedColor = c;	
		}
		
		public void setButtonsPerRow(int bpr)
		{
			_buttonsPerRow = bpr;
		}
		
		public void setSelected(int n)
		{
			_selected = n;
			repaint();
		}
		
		public int getSelected()
		{
			return _selected;
		}


// ***** METHODS - From MouseListener *********************************************

		/* (non-Javadoc)
		 * @see java.awt.event.MouseListener#mouseClicked(java.awt.event.MouseEvent)
		 */
		public void mouseClicked(MouseEvent arg0) {
			// TODO Auto-generated method stub
			
		}

		/* (non-Javadoc)
		 * @see java.awt.event.MouseListener#mousePressed(java.awt.event.MouseEvent)
		 */
		public void mousePressed(MouseEvent arg0) {
			// TODO Auto-generated method stub
			
		}

		/* (non-Javadoc)
		 * @see java.awt.event.MouseListener#mouseReleased(java.awt.event.MouseEvent)
		 */
		public void mouseReleased(MouseEvent e) 
		{
			int x = e.getX();
			int y = e.getY();
			int rx = x / _buttonSize.width;
			int ry = y / _buttonSize.height;
//			System.out.println("DEBUG: gridbutton mouse clicked at " + x + "," + y);
			if ( (rx >= _buttonsPerRow) || ((ry * _buttonsPerRow + rx) >= _numButtons) )
				return;
			_selected = ry * _buttonsPerRow + rx;
			repaint();
		}

		/* (non-Javadoc)
		 * @see java.awt.event.MouseListener#mouseEntered(java.awt.event.MouseEvent)
		 */
		public void mouseEntered(MouseEvent arg0) 
		{
		}

		/* (non-Javadoc)
		 * @see java.awt.event.MouseListener#mouseExited(java.awt.event.MouseEvent)
		 */
		public void mouseExited(MouseEvent arg0) 
		{
		}

}
