/* Vampire Attack 2 Construction Set
 * Copyright (C) 2009-2010 Blazing Games Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @author Billy D. Spelchan
 * @version 1.00
 */
package com.blazinggames.va2cs;

import java.awt.Point;

public interface TilemapListener 
{
	/**
	 * Called when the caller (TilemapViewer) has had a click within a tile.
	 * The mouse is still down at this point. If you are trying to capture a 
	 * rectangular region you could use this to determine the starting location
	 * and then use tileReleased for the ending location.
	 * 
	 * @param p point of tile on map
	 */
	public void tileSelected(Point p);

	/**
	 * Called when the caller (TilemapViewer) has been moved over a new tile.
	 * The mouse is still down at this point. This is useful if you want to be
	 * able to track the mouse as it is dragged over tiles (for something like
	 * drawing in a construction set).
	 * 
	 * @param p point of tile on map
	 */
	public void tileDragged(Point p);

	/**
	 * Called when the caller (TilemapViewer) has been released over a tile.
	 * It should be pointed out that this method may not be called if the mouse
	 * is released when it is outside of the component that is tracking the
	 * mouse movement. 
	 * 
	 * @param p point of tile on map
	 */
	public void tileReleased(Point p);
}
